==> apache-asterixdb-0.9.1-source-release.zip: apache-asterixdb-0.9.1/asterix-om/src/main/java/org/apache/asterix/om/functions/FunctionInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.om.functions;

import org.apache.asterix.common.functions.FunctionSignature;
import org.apache.hyracks.algebricks.core.algebra.functions.AbstractFunctionInfo;
import org.apache.hyracks.algebricks.core.algebra.functions.FunctionIdentifier;

public class FunctionInfo extends AbstractFunctionInfo {

    private static final long serialVersionUID = 1L;

    private final FunctionIdentifier functionIdentifier;

    public FunctionInfo(String namespace, String name, int arity, boolean isFunctional) {
        super(isFunctional);
        this.functionIdentifier = new FunctionIdentifier(namespace, name, arity);
    }

    public FunctionInfo() {
        super(true);
        functionIdentifier = null;
    }

    public FunctionInfo(FunctionIdentifier functionIdentifier, boolean isFunctional) {
        super(isFunctional);
        this.functionIdentifier = functionIdentifier;
    }

    public FunctionInfo(FunctionSignature functionSignature, boolean isFunctional) {
        super(isFunctional);
        this.functionIdentifier = new FunctionIdentifier(functionSignature.getNamespace(), functionSignature.getName(),
                functionSignature.getArity());
    }

    @Override
    public FunctionIdentifier getFunctionIdentifier() {
        return functionIdentifier;
    }

    @Override
    public int hashCode() {
        return toString().hashCode();
    }

    @Override
    public boolean equals(Object o) {
        if (!(o instanceof FunctionInfo)) {
            return false;
        }
        FunctionInfo info = (FunctionInfo) o;
        return functionIdentifier.equals(info.getFunctionIdentifier())
                && functionIdentifier.getArity() == info.getFunctionIdentifier().getArity();
    }

    @Override
    public String toString() {
        return this.functionIdentifier.getNamespace() + ":" + this.functionIdentifier.getName() + "@"
                + this.functionIdentifier.getArity();
    }

}

==> apache-asterixdb-0.9.4-source-release.zip: apache-asterixdb-0.9.4/asterix-om/src/main/java/org/apache/asterix/om/functions/FunctionInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.om.functions;

import java.util.List;

import org.apache.commons.lang3.mutable.Mutable;
import org.apache.hyracks.algebricks.core.algebra.base.ILogicalExpression;
import org.apache.hyracks.algebricks.core.algebra.functions.FunctionIdentifier;
import org.apache.hyracks.algebricks.core.algebra.functions.IFunctionInfo;

public class FunctionInfo implements IFunctionInfo {

    private final FunctionIdentifier functionIdentifier;
    private final boolean isFunctional;

    public FunctionInfo(String namespace, String name, int arity, boolean isFunctional) {
        this(new FunctionIdentifier(namespace, name, arity), isFunctional);
    }

    public FunctionInfo(FunctionIdentifier functionIdentifier, boolean isFunctional) {
        this.isFunctional = isFunctional;
        this.functionIdentifier = functionIdentifier;
    }

    @Override
    public FunctionIdentifier getFunctionIdentifier() {
        return functionIdentifier;
    }

    @Override
    public boolean isFunctional() {
        return isFunctional;
    }

    /**
     * @param args,
     *            the arguments.
     * @return a display string of the FunctionInfo.
     */
    @Override
    public String display(List<Mutable<ILogicalExpression>> args) {
        return FunctionDisplayUtil.display(this, args, input -> IFunctionInfo.super.display(input));
    }

    @Override
    public int hashCode() {
        return toString().hashCode();
    }

    @Override
    public boolean equals(Object o) {
        if (!(o instanceof FunctionInfo)) {
            return false;
        }
        FunctionInfo info = (FunctionInfo) o;
        return functionIdentifier.equals(info.getFunctionIdentifier())
                && functionIdentifier.getArity() == info.getFunctionIdentifier().getArity();
    }

    @Override
    public String toString() {
        return this.functionIdentifier.getNamespace() + ":" + this.functionIdentifier.getName() + "@"
                + this.functionIdentifier.getArity();
    }

}
